Crate smooth_operator

Crate smooth_operator 

Macros

checked
Convert arithmetic operators within the given expression to their checked variants and provide detailed error strings about which operator has failed for diagnostic.

Structs

Error
Checked arithmetics error.